@@ -101,7 +101,8 @@ main(int argc, char **argv)
     struct sockaddr_in6 sin6;
     int rc, fd, i, opt;
     time_t expiry_time, source_expiry_time, kernel_dump_time;
-    const char *config_file = NULL;
+    const char **config_files = NULL;
+    int num_config_files = 0;
     void *vrc;
     unsigned int seed;
     struct interface *ifp;
@@ -148,13 +149,13 @@ main(int argc, char **argv)
                 goto usage;
             break;
         case 'h':
-            default_wireless_hello_interval = parse_msec(optarg);
+            default_wireless_hello_interval = parse_thousands(optarg);
             if(default_wireless_hello_interval <= 0 ||
                default_wireless_hello_interval > 0xFFFF * 10)
                 goto usage;
             break;
         case 'H':
-            default_wired_hello_interval = parse_msec(optarg);
+            default_wired_hello_interval = parse_thousands(optarg);
             if(default_wired_hello_interval <= 0 ||
                default_wired_hello_interval > 0xFFFF * 10)
                 goto usage;
@@ -232,7 +233,13 @@ main(int argc, char **argv)
                 goto usage;
             break;
         case 'c':
-            config_file = optarg;
+            config_files = realloc(config_files,
+                                   (num_config_files + 1) * sizeof(char*));
+            if(config_files == NULL) {
+                fprintf(stderr, "Couldn't allocate config file.\n");
+                exit(1);
+            }
+            config_files[num_config_files++] = optarg;
             break;
         case 'C':
             rc = parse_config_from_string(optarg);
@@ -256,26 +263,31 @@ main(int argc, char **argv)
         }
     }
 
-    if(!config_file) {
-        if(access("/etc/babeld.conf", F_OK) >= 0)
-            config_file = "/etc/babeld.conf";
+    if(num_config_files == 0) {
+        if(access("/etc/babeld.conf", F_OK) >= 0) {
+            config_files = malloc(sizeof(char*));
+            if(config_files == NULL) {
+                fprintf(stderr, "Couldn't allocate config file.\n");
+                exit(1);
+            }
+            config_files[num_config_files++] = "/etc/babeld.conf";
+        }
     }
-    if(config_file) {
+
+    for(i = 0; i < num_config_files; i++) {
         int line;
-        rc = parse_config_from_file(config_file, &line);
+        rc = parse_config_from_file(config_files[i], &line);
         if(rc < 0) {
             fprintf(stderr,
                     "Couldn't parse configuration from file %s "
                     "(error at line %d).\n",
-                    config_file, line);
+                    config_files[i], line);
             exit(1);
         }
-    } else {
-        if(access("/etc/babel.conf", F_OK) >= 0)
-            fprintf(stderr,
-                    "Warning: /etc/babel.conf exists, it will be ignored.\n");
     }
 
+    free(config_files);
+
     if(default_wireless_hello_interval <= 0)
         default_wireless_hello_interval = 4000;
     default_wireless_hello_interval = MAX(default_wireless_hello_interval, 5);
@@ -990,9 +1002,8 @@ init_signals(void)
 }
 
 static void
-dump_route_callback(struct babel_route *route, void *closure)
+dump_route(FILE *out, struct babel_route *route)
 {
-    FILE *out = (FILE*)closure;
     const unsigned char *nexthop =
         memcmp(route->nexthop, route->neigh->address, 16) == 0 ?
         NULL : route->nexthop;
@@ -1034,9 +1045,8 @@ dump_route_callback(struct babel_route *route, void *closure)
 }
 
 static void
-dump_xroute_callback(struct xroute *xroute, void *closure)
+dump_xroute(FILE *out, struct xroute *xroute)
 {
-    FILE *out = (FILE*)closure;
     fprintf(out, "%s metric %d (exported)\n",
             format_prefix(xroute->prefix, xroute->plen),
             xroute->metric);
@@ -1046,23 +1056,47 @@ static void
 dump_tables(FILE *out)
 {
     struct neighbour *neigh;
+    struct xroute_stream *xroutes;
+    struct route_stream *routes;
 
     fprintf(out, "\n");
 
     fprintf(out, "My id %s seqno %d\n", format_eui64(myid), myseqno);
 
     FOR_ALL_NEIGHBOURS(neigh) {
-        fprintf(out, "Neighbour %s dev %s reach %04x rxcost %d txcost %d chan %d%s.\n",
+        fprintf(out, "Neighbour %s dev %s reach %04x rxcost %d txcost %d "
+                "rtt %s rttcost %d chan %d%s.\n",
                 format_address(neigh->address),
                 neigh->ifp->name,
                 neigh->reach,
                 neighbour_rxcost(neigh),
                 neigh->txcost,
+                format_thousands(neigh->rtt),
+                neighbour_rttcost(neigh),
                 neigh->ifp->channel,
                 if_up(neigh->ifp) ? "" : " (down)");
     }
-    for_all_xroutes(dump_xroute_callback, out);
-    for_all_routes(dump_route_callback, out);
+
+    xroutes = xroute_stream();
+    if(xroutes) {
+        while(1) {
+            struct xroute *xroute = xroute_stream_next(xroutes);
+            if(xroute == NULL) break;
+            dump_xroute(out, xroute);
+        }
+        xroute_stream_done(xroutes);
+    }
+
+    routes = route_stream(0);
+    if(routes) {
+        while(1) {
+            struct babel_route *route = route_stream_next(routes);
+            if(route == NULL) break;
+            dump_route(out, route);
+        }
+        route_stream_done(routes);
+    }
+
     fflush(out);
 }
 
@@ -1098,11 +1132,11 @@ reopen_logfile()
 static int
 kernel_routes_callback(int changed, void *closure)
 {
-    if (changed & CHANGE_LINK)
+    if(changed & CHANGE_LINK)
         kernel_link_changed = 1;
-    if (changed & CHANGE_ADDR)
+    if(changed & CHANGE_ADDR)
         kernel_addr_changed = 1;
-    if (changed & CHANGE_ROUTE)
+    if(changed & CHANGE_ROUTE)
         kernel_routes_changed = 1;
     return 1;
 }
