@@ -148,14 +148,14 @@ getint(int c, int *int_r, gnc_t gnc, void *closure)
 }
 
 static int
-getmsec(int c, int *int_r, gnc_t gnc, void *closure)
+getthousands(int c, int *int_r, gnc_t gnc, void *closure)
 {
     char *t;
     int i;
     c = getword(c, &t, gnc, closure);
     if(c < -1)
         return c;
-    i = parse_msec(t);
+    i = parse_thousands(t);
     if(i < 0) {
         free(t);
         return -2;
@@ -246,7 +246,7 @@ getid(int c, unsigned char **id_r, gnc_t gnc, void *closure)
 
 static int
 getnet(int c, unsigned char **p_r, unsigned char *plen_r, int *af_r,
-          gnc_t gnc, void *closure)
+       gnc_t gnc, void *closure)
 {
     char *t;
     unsigned char *ip;
@@ -408,13 +408,13 @@ parse_anonymous_ifconf(int c, gnc_t gnc, void *closure,
             if_conf->cost = cost;
         } else if(strcmp(token, "hello-interval") == 0) {
             int interval;
-            c = getmsec(c, &interval, gnc, closure);
+            c = getthousands(c, &interval, gnc, closure);
             if(c < -1 || interval <= 0 || interval > 10 * 0xFFFF)
                 goto error;
             if_conf->hello_interval = interval;
         } else if(strcmp(token, "update-interval") == 0) {
             int interval;
-            c = getmsec(c, &interval, gnc, closure);
+            c = getthousands(c, &interval, gnc, closure);
             if(c < -1 || interval <= 0 || interval > 10 * 0xFFFF)
                 goto error;
             if_conf->update_interval = interval;
@@ -464,6 +464,36 @@ parse_anonymous_ifconf(int c, gnc_t gnc, void *closure,
             if((if_conf->channel < 1 || if_conf->channel > 255) &&
                if_conf->channel != IF_CHANNEL_NONINTERFERING)
                 goto error;
+        } else if(strcmp(token, "enable-timestamps") == 0) {
+            int v;
+            c = getbool(c, &v, gnc, closure);
+            if(c < -1)
+                goto error;
+            if_conf->enable_timestamps = v;
+        } else if(strcmp(token, "rtt-decay") == 0) {
+            int decay;
+            c = getint(c, &decay, gnc, closure);
+            if(c < -1 || decay <= 0 || decay > 256)
+                goto error;
+            if_conf->rtt_decay = decay;
+        } else if(strcmp(token, "rtt-min") == 0) {
+            int rtt;
+            c = getthousands(c, &rtt, gnc, closure);
+            if(c < -1 || rtt <= 0)
+                goto error;
+            if_conf->rtt_min = rtt;
+        } else if(strcmp(token, "rtt-max") == 0) {
+            int rtt;
+            c = getthousands(c, &rtt, gnc, closure);
+            if(c < -1 || rtt <= 0)
+                goto error;
+            if_conf->rtt_max = rtt;
+        } else if(strcmp(token, "max-rtt-penalty") == 0) {
+            int cost;
+            c = getint(c, &cost, gnc, closure);
+            if(c < -1 || cost <= 0 || cost > 0xFFFF)
+                goto error;
+            if_conf->max_rtt_penalty = cost;
         } else {
             goto error;
         }
@@ -544,6 +574,11 @@ merge_ifconf(struct interface_conf *dest,
     MERGE(lq);
     MERGE(faraway);
     MERGE(channel);
+    MERGE(enable_timestamps);
+    MERGE(rtt_decay);
+    MERGE(rtt_min);
+    MERGE(rtt_max);
+    MERGE(max_rtt_penalty);
 
 #undef MERGE
 }
@@ -648,7 +683,7 @@ parse_option(int c, gnc_t gnc, void *closure, char *token)
     } else if(strcmp(token, "debug") == 0) {
         int d;
         c = getint(c, &d, gnc, closure);
-        if(d < 0)
+        if(c < -1 || d < 0)
             goto error;
         debug = d;
     } else if(strcmp(token, "diversity") == 0) {
@@ -773,7 +808,7 @@ gnc_file(struct file_state *s)
     int c;
     c = fgetc(s->f);
     if(c == '\n')
-       s->line++;
+        s->line++;
     return c;
 }
 
