@@ -164,7 +164,7 @@ check_interface_channel(struct interface *ifp)
             if(channel < 0)
                 fprintf(stderr,
                         "Couldn't determine channel of interface %s: %s.\n",
-                       ifp->name, strerror(errno));
+                        ifp->name, strerror(errno));
             if(channel <= 0)
                 channel = IF_CHANNEL_INTERFERING;
         }
@@ -303,7 +303,31 @@ interface_up(struct interface *ifp, int up)
         ifp->update_interval =
             IF_CONF(ifp, update_interval) > 0 ?
             IF_CONF(ifp, update_interval) :
-           ifp->hello_interval * 4;
+            ifp->hello_interval * 4;
+
+        ifp->rtt_decay =
+            IF_CONF(ifp, rtt_decay) > 0 ?
+            IF_CONF(ifp, rtt_decay) : 42;
+
+        ifp->rtt_min =
+            IF_CONF(ifp, rtt_min) > 0 ?
+            IF_CONF(ifp, rtt_min) : 10000;
+        ifp->rtt_max =
+            IF_CONF(ifp, rtt_max) > 0 ?
+            IF_CONF(ifp, rtt_max) : 120000;
+        if(ifp->rtt_max <= ifp->rtt_min) {
+            fprintf(stderr,
+                    "Uh, rtt-max is less than or equal to rtt-min (%d <= %d). "
+                    "Setting it to %d.\n", ifp->rtt_max, ifp->rtt_min,
+                    ifp->rtt_min + 10000);
+            ifp->rtt_max = ifp->rtt_min + 10000;
+        }
+        ifp->max_rtt_penalty = IF_CONF(ifp, max_rtt_penalty);
+
+        if(IF_CONF(ifp, enable_timestamps) == CONFIG_YES ||
+           (IF_CONF(ifp, enable_timestamps) == CONFIG_DEFAULT &&
+            ifp->max_rtt_penalty > 0))
+            ifp->flags |= IF_TIMESTAMPS;
 
         if(ifp->ll)
             free(ifp->ll);
@@ -405,7 +429,7 @@ interface_ll_address(struct interface *ifp, const unsigned char *address)
 
     for(i = 0; i < ifp->numll; i++)
         if(memcmp(ifp->ll[i], address, 16) == 0)
-           return 1;
+            return 1;
 
     return 0;
 }
