@@ -152,8 +152,10 @@ parse_nat(const char *string)
     return (int)l;
 }
 
+/* Given a fixed-point string such as "42.1337", returns 1000 times
+   the value of the string, here 42133. */
 int
-parse_msec(const char *string)
+parse_thousands(const char *string)
 {
     unsigned int in, fl;
     int i, j;
@@ -256,9 +258,9 @@ format_address(const unsigned char *address)
     static int i = 0;
     i = (i + 1) % 4;
     if(v4mapped(address))
-       inet_ntop(AF_INET, address + 12, buf[i], INET6_ADDRSTRLEN);
+        inet_ntop(AF_INET, address + 12, buf[i], INET6_ADDRSTRLEN);
     else
-       inet_ntop(AF_INET6, address, buf[i], INET6_ADDRSTRLEN);
+        inet_ntop(AF_INET6, address, buf[i], INET6_ADDRSTRLEN);
     return buf[i];
 }
 
@@ -293,6 +295,16 @@ format_eui64(const unsigned char *eui)
     return buf[i];
 }
 
+const char *
+format_thousands(unsigned int value)
+{
+    static char buf[4][15];
+    static int i = 0;
+    i = (i + 1) % 4;
+    snprintf(buf[i], 15, "%d.%.3d", value / 1000, value % 1000);
+    return buf[i];
+}
+
 int
 parse_address(const char *address, unsigned char *addr_r, int *af_r)
 {
