@@ -28,10 +28,14 @@ struct xroute {
     int proto;
 };
 
+struct xroute_stream;
+
 struct xroute *find_xroute(const unsigned char *prefix, unsigned char plen);
 void flush_xroute(struct xroute *xroute);
 int add_xroute(unsigned char prefix[16], unsigned char plen,
                unsigned short metric, unsigned int ifindex, int proto);
 int xroutes_estimate(void);
-void for_all_xroutes(void (*f)(struct xroute*, void*), void *closure);
+struct xroute_stream *xroute_stream();
+struct xroute *xroute_stream_next(struct xroute_stream *stream);
+void xroute_stream_done(struct xroute_stream *stream);
 int check_xroutes(int send_updates);
